@@ -158,15 +158,17 @@ class Act(object):
             rioinits = odict(ioinits)  # save copy registry ioinits to keep ival iown
             if self.prerefs:  # preinits ioinits dict items  'do for'
                 # each key is share src path, and value is list of src fields
-                inode = (self.ioinits or  odict()).get('inode', ioinits.get('inode', ''))
+                inode = (self.ioinits or odict()).get('inode', ioinits.get('inode', ''))
+                if inode and not inode.endswith("."):  # ensure is node not share path
+                    inode = "{0}.".format(inode)
                 for src, fields in self.prerefs.get('ioinits', {}).items():   # now resolve new src paths
                     src = self.resolvePath(ipath=src, inode=inode, warn=True) # now a share
                     if not fields:  # default is use existing fields
                         fields = self._prepareSrcFields(src, fields)
                     for field in fields:  # assumes each src fld value pre inited with ipath
-                        if field in src:  # only update if src has field
+                        if field in src and field != "inode":  # only update if src has field
                             ioinits[field] = src[field] # clobbers ioinit odict() with ipath
-            ioinits.update(self.ioinits or odict())  # 'do per', self.ioinits may be None
+            ioinits.update(self.ioinits or odict())  # 'do per', 'via inode', self.ioinits may be None
             for key, val in rioinits.items():  # restore registry ival iown defaults
                 if key in ioinits:  # check ipath overridden by for or per
                     # if new val not mapping and old val is mapping
@@ -179,10 +181,16 @@ class Act(object):
                 inode, iois = actor._initio(ioinits)
                 if iois:
                     for key, ioi in iois.items():
-                        share = actor._resolvePath(ipath=ioi['ipath'],
-                                                   ival=ioi.get('ival'),
-                                                   iown=ioi.get('iown'),
-                                                   inode=inode)
+                        if key == "inode":  # compute the final inode
+                            share = actor._resolvePath(ipath="",
+                                                       ival=ioi.get('ival'),
+                                                       iown=ioi.get('iown'),
+                                                       inode=ioi['ipath'])  # empty to force
+                        else:
+                            share = actor._resolvePath(ipath=ioi['ipath'],
+                                                       ival=ioi.get('ival'),
+                                                       iown=ioi.get('iown'),
+                                                       inode=inode)
                         if actor._Parametric:
                             if key in parms:
                                 msg = "ResolveError: Parm and Ioi with same name"
@@ -218,10 +226,14 @@ class Act(object):
         iown is optional ownership if True then overwrite if exists
                otherwise do not overwrite
 
-        inode is optional inode value for ipath used for ioinits
+        inode is optional actor inode value for ipath used for ioinits
 
         if warn then will complain if the share is created.
 
+        When ipath is empty then resolvePath returns the effective context node
+        path given the actor inode and nested frame inodes and framer inodes
+
+
         It allows for substitution into ipath of
         inode, framer,  main framer, frame, main frame, or actor relative names.
         So that lexically relative pathnames can
@@ -288,16 +300,16 @@ class Act(object):
         registry ioints are from the Actor.Ionints class variable
 
         So inode parameter to Act.resolvePaths inidcates if for ioinit or not.
-        If inode None then ipath is not an ioinit and Otherwise even if "" then
+        If inode None then ipath is not an actor ioinit and Otherwise even if "" then
         ipath comes from ioinit and  should handle inode logic.
         This would puts all the framer inode prepend
-        logic in one place and make it easier to climb the aux outline
-        or later add frame inodes
+        logic in one place and make it easier to climb the  frame and aux outline
 
         """
         if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
-            parts = ipath.split('.')  # assume ipath is not empty
-            if parts and parts[0]:  # not absolute so do relative substitutions
+            parts = ipath.split('.') if ipath else []  # [] if ipath is empty
+            noded = True if not parts else False  # return node path prefix context since empty ipath
+            if not parts or parts and parts[0]:  # empty or not empty and not absolute so do relative substitutions
                 if not self.frame:
                     raise excepting.ResolveError("ResolveError: Missing frame context"
                                              " to resolve relative pathname.", ipath, self,
@@ -306,35 +318,39 @@ class Act(object):
                     raise excepting.ResolveError("ResolveError: Missing framer context"
                                                  " to resolve relative pathname.", ipath, self.frame,
                                                  self.human, self.count)
-                frame = self.frame
+
                 framer = self.frame.framer
-                minode = framer.inode  # inode of framer first pass minode
-                fparts = minode.rstrip(".").split(".") if minode else []
-                mainer = framer.main.framer if framer.main else None  # main frame's framer
+                fparts = framer.inode.rstrip(".").split(".") if framer.inode else []
+                main = framer.main  # main frame
+                mainer = main.framer if main else None  # main frame's framer
                 # if mainer and not (absolute or framer relative)
-                # then fromer is aux framer so walk up mains processing finodes
-                # finode first because used by both inode and ipath logic below
+                # then fromer is aux framer so walk up mains processing inodes
+                # need to do this first because used by both inode and ipath logic below
                 while mainer and (not fparts or fparts[0] not in ("", "framer")):
-                    # five aux finode cases:
+                    # four aux inode cases:
                     # absolute: fparts[0] = "",
                     # framer relative: fparts[0] == "framer",
-                    # main: minode == "main"  first pass minode = finode
-                    # me relative: fparts[0] == "me",
                     # empty: fparts == [],
+                    # me relative: fparts[0] == "me",
                     # relative: otherwise
 
-                    # if not fparts or (fparts[0] != "me" and mparts != ["main"]):
-                        # future process frame via upper here
-                    # else skip frame via upper
+                    if fparts and fparts[0] == "me":
+                        del fparts[0]  # me relative
+                    else: # process over frame via inode
+                        while main and (not fparts or fparts[0] not in ("", "framer")):
+                            if main.inode:
+                                fparts = main.inode.rstrip(".").split(".") + fparts  # prepend
+                                if fparts and fparts[0] == "me":  # me relative
+                                    del fparts[0]
+                                    break  # skip any further over frames to main frame
+                            main = main.over  # walk up to over frame if any
+                        if fparts and fparts[0] in ("", "framer"):
+                            break
 
-                    # use minode == "main" here instead of mparts == ["main"] because
-                    # mparts == ["main"] for minode in ("main", "main.")
-                    if fparts and (fparts[0] == "me" or minode == "main"):
-                        del fparts[0]  # note fparts[0] = mparts[0] == minode
-                    minode = mainer.inode
-                    mparts = minode.rstrip(".").split(".") if minode else []
-                    fparts = mparts + fparts  # prepend mparts
-                    mainer = mainer.main.framer if mainer.main else None
+                    if mainer.inode:
+                        fparts = mainer.inode.rstrip(".").split(".") + fparts  # prepend
+                    main = mainer.main  # main framer's main frame walk up one level
+                    mainer = main.framer if main else None  # walk up one level
 
                 if fparts and fparts[0] == "me" :
                     del fparts[0]  # me not allowed as initial inode
@@ -342,17 +358,28 @@ class Act(object):
                 # "" == ".".join([]) == ".".join([""])
 
                 # already know from above parts not absolute
-                if parts[0] != 'me' and parts[0] != 'framer' and inode is not None:
+                if (inode is not None and (not parts or
+                        parts[0] not in ("framer", "me"))):
                     # prepend inode logic
                     iparts = inode.rstrip(".").split(".") if inode else []
                     if not iparts and not fparts:  # use default inode
                         iparts = "framer.me.frame.me.actor.me".split(".")
-                    parts = iparts + parts  # not extend in place
+                    parts = iparts + parts  # prepend inode parts
 
-                if parts and parts[0] not in ("", "framer"):  # not absolute or framer relative
-                    if parts[0] == 'me':
-                        del parts[0]
-                    parts = fparts + parts  # prepend fparts
+                if not parts or parts[0] not in ("", "framer"):  # not absolute or framer relative
+                    if parts and parts[0] == 'me':  # skip frame.inode processing
+                        del parts[0]  # parts could be empty now
+                    else:  # process frame.inode and walk up over if any
+                        frame = self.frame # start at current frame
+                        while frame and (not parts or parts[0] not in ("", "framer")):
+                            if frame.inode:
+                                parts = frame.inode.rstrip(".").split(".") + parts
+                            if parts and parts[0] == "me":
+                                del parts[0]
+                                break  # skip any further over frames
+                            frame = frame.over
+                    if not parts or parts[0] not in ("", "framer"):
+                        parts = fparts + parts  # prepend fparts
 
             if parts and parts[0]:  # not absolute so do relative substitutions
                 if parts[0] == 'framer':  #  framer relative addressing
@@ -397,6 +424,9 @@ class Act(object):
 
             ipath = '.'.join(parts)
 
+            if noded and ipath and not ipath.endswith("."):
+                ipath = "{0}.".format(ipath)
+
             if not self.frame.store:
                 raise excepting.ResolveError("ResolveError: Missing store context"
                                 " to resolve relative pathname.", ipath, self,
@@ -719,12 +749,12 @@ class Actor(object):
         if not isinstance(inode, basestring):
             raise ValueError("Nonstring inode arg '{0}'".format(inode))
 
-        if inode and not inode.endswith('.'):
+        if inode and not inode.endswith('.'):  # ensure is a node not share path
             inode = "{0}.".format(inode)
 
         iois = odict()
-        #ioi = odict(ipath=inode)  # create ioi for the inode not in kwa
-        #iois['inode'] = ioi  # inode path resolves first convenience when debugging
+        ioi = odict(ipath=inode)  # create ioi for the inode
+        iois['inode'] = ioi  # inode path resolves so actor has reference to its own inode
         for key, val in ioinits.items():  # assumes keys are basestrings
             if key == 'inode':  # skip inode
                 continue
@@ -755,16 +785,6 @@ class Actor(object):
             else:
                 raise ValueError("Bad ioinit for key '{0}' with value '{1}'".format(key, val))
 
-            #if ipath:
-                #if not ipath.startswith('.'): # full path is inode joined to ipath
-                    #if not(ipath.startswith('me.') or ipath == 'me'):  # do not override inode
-                        #ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
-                    ## any paths starting with me with have the framer inode (frinode) substituted
-                    ## in act.resolvepath called by actor._resolvePath later
-                    ## this allows override of doer inode prepend
-            #else: # empty ipath
-                #ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
-
             # inode is prepended in act.resolvePath
 
             if not ipath:
